.. highlight:: shell

============
Installation
============

At the command line::

    $ pip install --user nbawebstats

Or, with virtualenvwrapper installed::

    $ mkvirtualenv nbawebstats
    $ pip install nbawebstats
